package com.yeejoin.amos.api.householdapi.face.service;

import com.yeejoin.amos.api.householdapi.face.orm.houseapi.entity.hygf.JpStation;
import com.yeejoin.amos.api.householdapi.face.orm.houseapi.entity.tdeingine.SofarInverter;
import com.yeejoin.amos.api.householdapi.face.orm.houseapi.entity.tdeingine.SofarStationList;

import java.util.List;
import java.util.Map;

public interface SofarDataAcquisitionService {
    /**
     * @descrption 场站列表数据入库
     */
    void stationList();
    /**
     * @descrption 场站详情数据入库
     */
    void stationDetail(List<SofarStationList> jsonObject);
    /**
     * @descrption 采集器列表数据入库
     */
    void collectorList( List<SofarStationList> jsonObject);
    /**
     * @descrption 采集器详情数据入库
     */
    void collectorDetail();
    /**
     * @descrption 逆变器列表数据入库
     */
    void inverterList(SofarInverter sofarInverter, JpStation jpStation, Map<String, String> maps);
    /**
     * @descrption 逆变器详情数据入库
     */
    void inverterDetail();
    /**
     * @descrption 采集器告警列表数据入库
     */
    void inverAlramInfo();
}
